@@ -1,4 +1,5 @@
-use crate::client::client_types::{terra_f64_format, terra_u64_format};
+use crate::client::client_types::{terra_datetime_format, terra_f64_format, terra_u64_format};
+use chrono::{DateTime, Utc};
 
 use crate::core_types::Coin;
 use crate::messages::Message;
@@ -43,6 +44,22 @@ pub struct TxResultBlockEvent {
     pub s_type: String,
     pub attributes: Vec<TxResultBlockAttribute>,
 }
+impl TxResultBlockEvent {
+    /// get all key/values from the event that have the key 'key'
+    pub fn get_attribute(&self, key: &str) -> Vec<TxResultBlockAttribute> {
+        self.attributes
+            .iter()
+            .filter(|attr| attr.key == key)
+            .cloned()
+            .collect()
+    }
+    /// return the first value of the first attribute that has the key 'key'
+    pub fn get_first_value(&self, key: &str) -> Option<String> {
+        self.get_attribute(key)
+            .first()
+            .map(|attr| attr.value.clone().unwrap_or_default())
+    }
+}
 #[derive(Deserialize, Clone, Serialize, Debug)]
 pub struct TxResultBlockMsg {
     pub msg_index: Option<usize>,
@@ -59,6 +76,8 @@ pub struct TXResultBlock {
     pub code: Option<usize>,
     pub raw_log: String,
     pub logs: Option<Vec<TxResultBlockMsg>>,
+    #[serde(with = "terra_datetime_format")]
+    pub timestamp: DateTime<Utc>,
     // #[serde(with = "terra_u64_format")]
     // pub gas_wanted: u64,
     // #[serde(with = "terra_u64_format")]
@@ -74,6 +93,7 @@ impl TXResultBlock {
         attribute_key: &str,
     ) -> Vec<(usize, String)> {
         let mut response: Vec<(usize, String)> = Default::default();
+
         if let Some(logs) = &self.logs {
             for log_part in logs {
                 let msg_index = log_part.msg_index.unwrap_or_default();
@@ -101,6 +121,25 @@ impl TXResultBlock {
         }
         response
     }
+    /// get the list of event types from a TX record
+    pub fn get_events(&self, event_type: &str) -> Vec<TxResultBlockEvent> {
+        let mut response: Vec<TxResultBlockEvent> = Default::default();
+
+        if let Some(logs) = &self.logs {
+            for log_part in logs {
+                let events = &log_part.events;
+                //      log::info!("logs{:?}", events);
+                let events_filtered = events
+                    .iter()
+                    .filter(|event| event.s_type == event_type)
+                    .collect::<Vec<_>>();
+                for event in events_filtered {
+                    response.push(event.clone());
+                }
+            }
+        }
+        response
+    }
 }
 #[derive(Serialize)]
 pub struct TxEstimate2<'a> {
